<?php
class Main extends Controller {
	
	var $errorMes;
	
	function Main() {
		parent::Controller();
		
		$this->errorMes = null;
		$this->output->enable_profiler(TRUE);
	}
	
	/**
	 * Отображает главную страницу с таблицей результатов
	 */
	function index() {
		$this->load->model('resultmodel');
		$this->load->helper('form');
		
		$resData = $this->resultmodel->getGeneralData();
		$pageData['results'] = $resData;
		
		$pageData['title'] = "Simple URL checker - Главная";
		$pageData['error'] = $this->errorMes;
		$this->load->view('header', $pageData);
		$this->load->view('mainpage');
		$this->load->view('footer');
	}
	
	/**
	 * Отображает страницу с таблицей результатов проверок заданного URL
	 *
	 * @param $urlId - значение поля urlId в базе данных (таблица results)
	 */
	function urldetails($urlId) {
		if (!isset($urlId) || !is_numeric($urlId) || $urlId <= 0) {
			redirect('main/index');
		}
		$this->load->model('resultmodel');
		$this->load->helper('form');
		
		$urlInfo = $this->resultmodel->getUrlData($urlId);

		$pageData['title'] = "Simple URL checker - подробно";
		$pageData['urlInfo'] = $urlInfo;
		$pageData['urlId'] = $urlId;
		
		$this->load->view('header', $pageData);
		$this->load->view('urldetails');
		$this->load->view('footer');
	}
	
	/**
	 * Добавляет новый URL
	 *
	 * @param newurl (передается в массиве $_POST) 
	 */
	function addurl() {
		$this->load->helper('form');
		$this->load->model('urlmodel');
		$url = $this->input->post('newurl');
		if ($url !== FALSE && $this->_isValidURL($url)) {
			$id = $this->urlmodel->addURL($url);
		}
		else {
			$this->errorMes = "Некорректный URL";
		}
		$this->index();
	}

	/**
	 * Отправляет запрос (и сохраняет его результаты) по указанным URL
	 *
	 * @param $urlId - значение поля urlId в базе данных (таблица results),
	 * если не задан или равен 0 - нужно пропинговать все URL из базы
	 */
	function ping($urlId = 0) {
		$this->load->model('urlmodel');
		$this->load->model('resultmodel');
		$urls = array();
		if ($urlId == 0) {
			//получаем полный список URL из БД
			$urls = $this->urlmodel->getAllUrls();
		}
		else {
			//ищем выбранный URL
			$urls = $this->urlmodel->getUrlById($urlId);
		}
		if ($urls !== FALSE) {
			//создаем обработчик для параллельной работы с URL'ами
			$mh = curl_multi_init();
			//создаем обработчики для каждого отдельного URL и добавляем их в $mh
			$handles = array();
			for ($i = 0; $i < count($urls); $i++) {
				$handles[$i] = curl_init();
				curl_setopt($handles[$i], CURLOPT_URL, $urls[$i]['URL']);
				curl_setopt($handles[$i], CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($handles[$i], CURLOPT_FOLLOWLOCATION, 1);
				curl_setopt($handles[$i], CURLOPT_TIMEOUT, 10);
				curl_setopt($handles[$i], CURLOPT_HEADER, 0);
				//если используется прокси, нужно указать его порт и ip
				//curl_setopt($handles[$i], CURLOPT_PROXYPORT, "8080");
				//curl_setopt($handles[$i], CURLOPT_PROXY, "192.168.0.1");
				
				curl_multi_add_handle($mh, $handles[$i]);
			}
			//запускаем обработку
			$running = null;
			do {
				curl_multi_exec($mh, $running);
			} while ($running > 0);
			//получаем данные и сохраняем их в БД
			for ($i = 0; $i < count($urls); $i++) {
				$urlInfo = curl_getinfo($handles[$i]);
				$resData['urlId'] = $urls[$i]['id'];
				if ($urlInfo['speed_download'] != 0) {
					$resData['result'] = 1;
				}
				else {
					$resData['result'] = 0;
				}
				$resData['responsetime'] = $urlInfo['total_time'];
				$resData['responselength'] = $urlInfo['size_download'];
				$resData['responsespeed'] = $urlInfo['speed_download'];
				$this->resultmodel->saveResults($resData);
			}
			//закрываем обработчики
			for ($i = 0; $i < count($handles); $i++) {
				curl_multi_remove_handle($mh, $handles[$i]);
			}
			if ($urlId == 0) {
				$this->index();
			}
			else {
				$this->urldetails($urlId);
			}
		}
	}
	
	/**
	 * Проверяет формат URL
	 *
	 * @param строка, содержащая URL
	 * @return TRUE - если URL имеет правильный формат, FALSE - если нет
	 */
	function _isValidURL($url) {
		$strRegex = "/^[a-zA-Z0-9]+:\/\/[^ ]+$/";
        return preg_match($strRegex, $url);
	}
	
	/**
	 * Удаляет результат проверки URL
	 *
	 * @param $urlId - значение поля urlId в базе данных (таблица results)
	 * @param $id - значение поля id в базе данных (таблица results)
	 */
	function removeresult($urlId, $id) {
		$this->load->model('resultmodel');
		$this->resultmodel->removeResult($id);
		$this->urldetails($urlId);
	}
	
	/**
	 * Удаляет URL из базы данных
	 *
	 * @param $urlId - значение поля id в базе данных (таблица urls)
	 */
	function removeurl($urlId) {
		if (isset($urlId) && is_numeric($urlId) && $urlId > 0) {
			$this->load->model('urlmodel');
			$this->urlmodel->deleteURL($urlId);
		}
		$this->index();
	}
}
?>