<?php
class ResultModel extends Model {
	
	function ResultModel() {
		parent::Model();
	}
	
	/**
	 * Этот метод сохраняет результаты запроса URL
	 *
	 * @param массив с результатами
	 * @return TRUE - если данные успешно сохранены в БД, FALSE - в случае ошибки
	 */
	function saveResults($resultsData) {
		if (!isset($resultsData)) {
			return false;
		}
		$qSave = "INSERT INTO results VALUES (NULL, ?, NULL, ?, ?, ?, ?)";
		$res = $this->db->query($qSave, array(
										$resultsData['urlId'],
										$resultsData['result'],
										$resultsData['responsetime'],
										$resultsData['responselength'],
										$resultsData['responsespeed']));
		return $res;
	}
	
	/**
	 * Возвращает всю информацию о результатах проверки заданного URL
	 *
	 * @param идентификатор URL
	 * @return массив с данными для указанного URL, FALSE - если ничего не найдено
	 */
	function getURLData($urlId) {
		if (!isset($urlId) || !is_numeric($urlId) || $urlId <= 0) {
			return false;
		}
		$qGetUrlData = "SELECT results.id, results.checktime, results.result, "
			."results.responsetime, results.responselength, results.responsespeed, "
			."urls.url FROM results, "
			."urls WHERE results.urlId=? AND urls.id=results.urlId";
		$res = $this->db->query($qGetUrlData, array($urlId));
		if ($res->num_rows() == 0) {
			return false;
		}
		else {
			return $res->result_array();
		}
	}
	
	/**
	 * Возвращает краткую информацию о проверках по всем URL
	 *
	 * @return массив с данными проверок, FALSE - если ничего не найдено
	 */
	function getGeneralData() {
		$qGetAll = "SELECT ".
			"urls.id, ".
			"urls.url, ".
			"COUNT(results.result) AS totalRequests, ".
			"COUNT(results.result)-SUM(results.result) AS totalErrors, ".
			"SUM(results.responsetime)/NULLIF(SUM(results.result), 0) AS avgResponse, ".
			"SUM(results.responselength)/NULLIF(SUM(results.result), 0) AS avgLength, ".
			"SUM(results.responsespeed)/NULLIF(SUM(results.result), 0) AS avgSpeed ".
			"FROM urls ".
			"LEFT JOIN results ON results.urlId=urls.id ".
			"GROUP BY urls.id";
		$res = $this->db->query($qGetAll);
		if ($res->num_rows() == 0) {
			return false;
		}
		else {
			return $res->result_array();
		}
	}
	
	/**
	 * Удаляет результат проверки
	 *
	 * @param id результата
	 * @return TRUE - если результат удален, FALSE - в противном случае
	 */
	function removeResult($id) {
		if (isset($id) && is_numeric($id) && $id > 0) {
			$qRemoveRes = "DELETE FROM results WHERE id=?";
			return $this->db->query($qRemoveRes, array($id));
		}
		else {
			return false;
		}
	}
}
?>