<?php
class UrlModel extends Model {
	
	function UrlModel() {
		parent::Model();
	}
	
	/**
	 * Возвращает массив со всеми URL
	 *
	 * @return массив с URL, FALSE - если URL не найдены
	 */
	function getAllUrls() {
		$qGetAllUrls = "SELECT * FROM urls";
		$res = $this->db->query($qGetAllUrls);
		if ($res->num_rows() == 0) {
			return false;
		}
		else {
			return $res->result_array();
		}
	}
	
	/**
	 * Ищет URL по заданному id
	 *
	 * @param идентификатор URL в БД
	 * @return если URL найден, возвращает массив с URL и его id,
	 * FALSE - в противном случае
	 */
	function getUrlById($urlId) {
		if (!isset($urlId) || !is_numeric($urlId) || $urlId <= 0) {
			return false;
		}
		$qGetUrl = "SELECT * FROM urls WHERE id=?";
		$res = $this->db->query($qGetUrl, array($urlId));
		if ($res->num_rows() == 0) {
			return false;
		}
		else {
			return $res->result_array();
		}
	}
	
	/**
	 * Этот метод добавляет URL в таблицу
	 *
	 * @param URL (включая http://)
	 * @return id новой записи (если URL был добавлен), FALSE - в противном случае
	 */
	function addURL($url) {
		if (!isset($url) || $url == "") {
			return false;
		}
		$qAddURL = "INSERT INTO urls (id, url) VALUES (NULL, ?)";
		$res = $this->db->query($qAddURL, array($url));
		if ($res === TRUE) {
			return $this->db->insert_id();
		}
		return $res;
	}
	
	/**
	 * Этот метод удаляет URL из базы данных.
	 * Автоматически удаляются все результаты запросов для данного URL.
	 *
	 * @param идентификатор URL в БД
	 * @return TRUE - если URL был удален, FALSE - в случае ошибки
	 */
	function deleteURL($urlId) {
		if (!isset($urlId) || !is_numeric($urlId) || $urlId <= 0) {
			return false;
		}
		$qDeleteUrl = "DELETE FROM urls WHERE id=?";
		$res = $this->db->query($qDeleteUrl, array($urlId));
		return $res;
	}
	
	/**
	 * Этот метод обновляет URL в базе данных.
	 * Удобно использовать если URL сайта изменился.
	 *
	 * @param идентификатор URL в БД
	 * @param новый URL
	 * @return TRUE - если URL был изменен, FALSE - в случае ошибки
	 */
	function updateURL($urlId, $newUrl) {
		if (!isset($urlId) || !is_numeric($urlId) || $urlId <= 0 || !isset($url) || $url == "") {
			return false;
		}
		$qUpdateUrl = "UPDATE urls SET url=? WHERE id=?";
		$res = $this->db->query($qUpdateUrl, array($newUrl, $urlId));
		return $res;
	}
}
?>